#ifndef _TERMPTY_GFX_H__
#define _TERMPTY_GFX_H__ 1

#include "termpty.h"

Eina_Unicode _termpty_charset_trans(const Termpty *ty, Eina_Unicode g);

#endif
